@@ -18,17 +18,22 @@ import multiprocessing
 import base64
 import json
 import os
+import platform
 import re
 import threading
 import time
-
+import ctypes
+from ctypes import *
+from subprocess import *
+from .selenium_phantomjs.webdriver.remote import webdriver
 from .Item import Item
-
 from .Connection import Connection
 from .Events import Events
 import configparser
 from multiprocessing import Process, Pipe
 from .Watcher import *
+import psutil
+import warnings
 
 
 def _watcher_process(main_pid, host, port, conn):
@@ -42,6 +47,28 @@ def _start_watcher(host, port, watcher_conn):
     watcher_process.start()
 
 
+def _web_driver_daemon(main_pid, wb_pid, parent_pid):
+    psutil.Process(parent_pid).kill()
+    main_process = psutil.Process(main_pid)
+    wb_process = psutil.Process(wb_pid)
+    while main_process.is_running():
+        time.sleep(3)
+    wb_process.kill()
+    exit(0)
+
+
+def _create_orphan_thread(main_pid, wb_pid):
+    wb_daemon_process = Process(target=_web_driver_daemon, args=(main_pid, wb_pid, os.getpid()))
+    wb_daemon_process.daemon = False
+    wb_daemon_process.start()
+
+
+def _start_web_driver_daemon(wb_pid):
+    orphan_thread = Process(target=_create_orphan_thread, args=(os.getpid(), wb_pid))
+    orphan_thread.daemon = False
+    orphan_thread.start()
+
+
 class Device(Events):
     con = Connection()
     __osVersion = ""
@@ -61,21 +88,57 @@ class Device(Events):
     __width = 0
     __height = 0
     __syslog_tid = None
+    """
+    control_host_type:
+        0: anywhere
+        1: windows amd64
+        2: linux x86_64
+        3: darwin x86_64
+    """
+    control_host_type = 0
 
     def __init__(self, host="192.168.100.100", port=10008, main=True):
         super().__init__(d=self)
+        warnings.simplefilter('ignore', ResourceWarning)
         self.con.host = host
         self.con.port = port
         self.con.connect()
+        self.__path = os.path.realpath(__file__).split(os.path.basename(__file__))[0]
         self.__serialNumber = str(self.con.get(path="getSerialNumber").read(), 'utf-8')
         self.__osVersion = str(self.con.get(path="getOsVersion").read(), 'utf-8')
         self.__set_display_size()
         if main:
-            _start_watcher(host, port, self.__watcher_conn)
+            self.__check_platform()
+            if self.control_host_type != 0:
+                _start_web_driver_daemon(self.__wb_process.pid)
+                _start_watcher(host, port, self.__watcher_conn)
             syslog_thread = threading.Thread(target=self.__logger)
             syslog_thread.setDaemon(True)
             syslog_thread.start()
         self.refresh_layout()
+        if self.control_host_type != 0:
+            self.webdriver = webdriver.WebDriver(command_executor='http://127.0.0.1:8910/wd/hub')
+
+    def __check_platform(self):
+        p = platform.system()
+        m = platform.machine()
+        if p == "Windows" and m == "AMD64":
+            self.control_host_type = 1
+            self.__init_webdriver("win32_x86_64_phantomjs", "libsimulation-rendering.dll")
+        elif p == "Linux" and m == "x86_64":
+            self.control_host_type = 2
+            self.__init_webdriver("linux_x86_64_phantomjs", "libsimulation-rendering.so")
+        elif p == "Darwin" and m == "x86_64":
+            self.control_host_type = 3
+            self.__init_webdriver("darwin_x86_64_phantomjs", "libsimulation-rendering.dylib")
+
+    def __init_webdriver(self, p_name, l_name):
+        self.__wb_process = Popen([self.__path + "data/" + p_name, self.__path + "data/ghostdriver/main.js", str(self.__width), str(self.__height)], stdout=PIPE, stderr=PIPE)
+        for i in range(2):
+            self.__wb_process.stdout.readline()
+        ll = cdll.LoadLibrary
+        self.libsr = ll(self.__path + "data/" + l_name)
+        self.libsr.go.restype = ctypes.c_char_p
 
     def push_watcher_data(self):
         self.__main_conn.send({'watcher_list': self.watcher_list})
