@@ -93,23 +93,23 @@ class Events:
         return self.__reply_status_check(self.device.con.get(path="sendCommitString", args="str=" + urllib.parse.quote(text)))
 
     def click(self, x, y, delay=0):
-        return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + str(x) + "|" + str(y) + "&delay=" + str(delay)))
+        return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + str(round(x)) + "|" + str(round(y)) + "&delay=" + str(delay)))
 
     def multi_click(self, points, delay=0):
         args = ""
         for point in points:
-            args += str(point[0]) + "|" + str(point[1])
+            args += str(round(point[0])) + "|" + str(round(point[1]))
             if points.index(point) != len(points) - 1:
                 args += ","
         return self.__reply_status_check(self.device.con.get(path="sendTouchEvent", args="points=" + args + "&delay=" + str(delay)))
 
     def swipe(self, x1, y1, x2, y2):
-        return self.__reply_status_check(self.device.con.get(path="sendSlideEvent", args="sliders=" + str(x1) + "|" + str(y1) + "->" + str(x2) + "|" + str(y2)))
+        return self.__reply_status_check(self.device.con.get(path="sendSlideEvent", args="sliders=" + str(round(x1)) + "|" + str(round(y1)) + "->" + str(round(x2)) + "|" + str(round(y2))))
 
     def multi_swipe(self, points1, points2):
         args = ""
         for point1 in points1:
-            args += str(point1[0]) + "|" + str(point1[1]) + "->" + str(points2[points1.index(point1)][0]) + "|" + str(points2[points1.index(point1)][1])
+            args += str(round(point1[0])) + "|" + str(round(point1[1])) + "->" + str(round(points2[points1.index(point1)][0])) + "|" + str(round(points2[points1.index(point1)][1]))
             if points1.index(point1) != len(points1) - 1:
                 args += ","
         return self.__reply_status_check(self.device.con.get(path="sendSlideEvent", args="sliders=" + args))
